@@ -75,6 +75,10 @@ LoginDialog::LoginDialog(Spotify::Session* pSession, QSettings* pSettings, QWidg
     m_Layout.addWidget(&m_SaveCredentials,2,1,1,-1);
     m_Layout.addWidget(&m_PreferredBitrate,3,1,1,-1);
     m_Layout.addWidget(&m_LoginBtn,4,1);
+    m_Layout.setRowStretch(1,1);
+    m_Layout.setRowStretch(2,1);
+    m_Layout.setRowStretch(3,1);
+    m_Layout.setRowStretch(4,50);
 
     setLayout(&m_Layout);
 }
@@ -166,6 +170,9 @@ void LoginDialog::resetState()
 void LoginDialog::OnOrientationChanged()
 {
     //device orientation changed (e.g, screen rotate)
+
+   // QSizePolicy policy(QSizePolicy::Fixed,QSizePolicy::Fixed);
+
     QRect screenGeometry = QApplication::desktop()->screenGeometry(); // get current screen geometry
     if (screenGeometry.width() > screenGeometry.height())
     {
@@ -177,7 +184,6 @@ void LoginDialog::OnOrientationChanged()
     {
         //switch to portrait mode
         m_SaveCredentials.setText(tr("Remember UserID && Pwd"));
-        setFixedSize(APP_HEIGHT,APP_WIDTH); //resize dialog to fixed size
     }
 }
 
